MyImg :: Processing of micrographs
----------------------------------

* MyImg contains tools for the processing of microscopic images.
* The package is under development, but some basic tools do work.

Quick start
-----------

* TODO

Documentation, help and examples
--------------------------------

* TODO

Versions of MyImg
-----------------

* Version 0.1 = 1st draft, too complex, later completely re-written 
* Version 0.2 = 2nd draft, better concept; functions: cut, crop, label, scalebar
* Version 0.3 = TODO: scalebar/stripes, montage, description, border...
